
package Paws::EMR::AddTagsOutput;
  use Moose;


### main pod documentation begin ###

=head1 NAME

Paws::EMR::AddTagsOutput

=head1 ATTRIBUTES



=cut

1;